@@ -592,7 +592,7 @@ class P2PShuffle(SimpleShuffle):
             _barrier_key,
             p2p_barrier,
             token,
-            transfer_keys,
+            *transfer_keys,
             spec=DataFrameShuffleSpec(
                 id=shuffle_id,
                 npartitions=self.npartitions_out,
